<?php

namespace Drupal\employee_list\Controller;

use Drupal\Core\Controller\ControllerBase;

/**
 * EmployeeListControllerクラス
 */
class EmployeeListController extends ControllerBase {

  /**
   *  employeeテーブルからのリストの取得
   */
  function queryEmployeeList($header) {

    // employeeテーブルのqueryを行う
    $query = \Drupal::database()->select('employee', 'emp');
    $query->fields('emp', ['employee_id','dept_code','name','kana','position','telephone','mail']);
    // ヘッダーにソート項目を指定
    $table_sort = $query->extend('Drupal\Core\Database\Query\TableSortExtender')->orderByHeader($header);
    // ページャーを使用。表示件数：5行
    $pager = $table_sort->extend('Drupal\Core\Database\Query\PagerSelectExtender')->limit(5);
    $results = $pager->execute()->fetchAll();

    // 出力用の配列を初期化
    $output = array();

    // query結果を出力用の配列にセット
    foreach ($results as $row) {
      $output[] = [
        'employee_id' => $row->employee_id,
        'dept_code' => $row->dept_code,
        'name' => $row->name,
        'kana' => $row->kana,
        'position' => $row->position,
        'telephone' => $row->telephone,
        'mail' => $row->mail,
      ];
    }

    return $output;
  }

  /**
   * employeeテーブルの一覧表示
   *
   * @return array
   *   Return markup array.
   */
  public function list() {

    // 'field'で指定された項目がソート項目となる
    $header = [
      [ 'data' => '社員ID',     'field' => 'employee_id', 'sort' => 'asc' ],
      [ 'data' => '部門コード', 'field' => 'dept_code' ],
      [ 'data' => '名前',       ],
      [ 'data' => 'カナ',       'field' => 'kana' ],
      [ 'data' => '職位',       ],
      [ 'data' => '電話',       ],
      [ 'data' => 'メール',     ], 
    ];

    $output = $this->queryEmployeeList($header);

    $form['table'] = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $output,
      '#empty' => 'データがありません',
    ];

    // pagerの表示
    $form['pager'] = [
      '#type' => 'pager'    
    ];

    return $form;
  }

}

